@@ -1,6 +1,7 @@
 import click
 from cosmoglobe.plot.click_plotting import commands_plotting
 from cosmoglobe.h5.click_h5 import commands_h5
+from cosmoglobe.fits.click_fits import commands_fits
 
 CONTEXT_SETTINGS = dict(max_content_width=100)
 
@@ -8,7 +9,7 @@ CONTEXT_SETTINGS = dict(max_content_width=100)
 def cli():
     pass
 
-cli = click.CommandCollection(sources=[commands_plotting, commands_h5], context_settings=CONTEXT_SETTINGS)
+cli = click.CommandCollection(sources=[commands_plotting, commands_h5, commands_fits], context_settings=CONTEXT_SETTINGS)
 
 if __name__ == '__main__':
     cli()
