@@ -33,12 +33,7 @@ DEFAULT_FONTSIZES = {
     "llabel": 11,
     "rlabel": 11,
 }
-FIGURE_WIDTHS = {
-    "x": 2.75,
-    "s": 3.5,
-    "m": 4.7,
-    "l": 7,
-}
+
 STOKES = [
     "I",
     "Q",
@@ -50,7 +45,7 @@ def set_style(darkmode=False, font="serif"):
     """
     This function sets the color parameter and text style
     """
-    if font=="serif":
+    if font == "serif":
         plt.rc(
             "font",
             family="serif",
@@ -67,8 +62,8 @@ def set_style(darkmode=False, font="serif"):
         "font.size": 11,
         # Make the legend/label fonts a little smaller
         "legend.fontsize": 8,
-        "xtick.labelsize": 8,
-        "ytick.labelsize": 8,
+        "xtick.labelsize": 11,
+        "ytick.labelsize": 11,
     }
     plt.rcParams.update(
         tex_fonts,
@@ -93,20 +88,49 @@ def set_style(darkmode=False, font="serif"):
             plt.rcParams[p] = "black"
 
 
-def make_fig(
-    figsize, fignum, hold, sub, reuse_axes, darkmode=False, projection=None
-):
+def get_figure_width(width=600, fraction=1):
+    """Set figure dimensions to avoid scaling in LaTeX.
+
+    Parameters
+    ----------
+    width: float
+            Document textwidth or columnwidth in pts
+    fraction: float, optional
+            Fraction of the width which you wish the figure to occupy
+
+    Returns
+    -------
+    fig_dim: tuple
+            Dimensions of figure in inches
+    """
+    # Width of figure (in pts)
+    fig_width_pt = width * fraction
+
+    # Convert from pt to inches
+    inches_per_pt = 1 / 72.27
+
+    # Golden ratio to set aesthetic figure height
+    # https://disq.us/p/2940ij3
+    golden_ratio = (5**0.5 - 1) / 2
+
+    # Figure width in inches
+    fig_width_in = fig_width_pt * inches_per_pt
+    # Figure height in inches
+    fig_height_in = fig_width_in * golden_ratio
+
+    # Proper scaling
+    fig_dim = (fig_width_in, fig_height_in)
+    #print(f"Using dimensions: {fig_dim}")
+    return fig_dim
+
+
+def make_fig(figsize, fignum, hold, sub, reuse_axes, darkmode=False, projection=None, fraction=0.5):
     """
     Create matplotlib figure, add subplot, use current axes etc.
     """
 
     if figsize is None:
-        fig_width_pt = 246.0  # Get this from LaTeX using \showthe\columnwidth
-        inches_per_pt = 1.0 / 72.27  # Convert pt to inch
-        golden_mean = (np.sqrt(5) - 1.0) / 2.0  # Aesthetic ratio
-        fig_width = fig_width_pt * inches_per_pt  # width in inches
-        fig_height = fig_width * golden_mean  # height in inches
-        figsize = [fig_width, fig_height]
+        figsize = get_figure_width(fraction=fraction)
 
     #  From healpy
     nrows, ncols, idx = (1, 1, 1)
@@ -139,9 +163,7 @@ def make_fig(
             fig = plt.figure(figsize=figsize)
 
         if idx < 1 or idx > ncols * nrows:
-            raise ValueError(
-                "Wrong values for subplot: %d, %d, %d" % (nrows, ncols, idx)
-            )
+            raise ValueError("Wrong values for subplot: %d, %d, %d" % (nrows, ncols, idx))
 
     if reuse_axes:
         ax = fig.gca()
@@ -176,12 +198,12 @@ def fmt(x, pos):
         elif float(a) == -1.00:
             return r"$-10^{" + str(b) + "}$"
         else:
-            return fr"${a} \cdot 10^{b}$"
+            return rf"${a} \cdot 10^{b}$"
     elif abs(x) > 1e1 or (float(abs(x))).is_integer():
-        return fr"${int(x):d}$"
+        return rf"${int(x):d}$"
     else:
         x = round(x, 2)
-        return fr"${x}$"
+        return rf"${x}$"
 
 
 def format_list(items):
@@ -193,7 +215,7 @@ def symlog(m, linthresh=1.0):
     This is the semi-logarithmic function used when logscale=True
     """
     if linthresh == 0.0:
-        return np.sign(m)*np.log10(1e-20 + abs(m))
+        return np.sign(m) * np.log10(1e-20 + abs(m))
 
     # Extra fact of 2 ln 10 makes symlog(m) = m in linear regime
     m = m / linthresh / (2 * np.log(10))
@@ -285,9 +307,7 @@ def gradient_fill(x, y, fill_color=None, ax=None, alpha=1.0, invert=False, **kwa
     xmin, xmax, ymin, ymax = x.min(), x.max(), y.min(), y.max()
     if invert:
         ymin, ymax = (ymax, ymin)
-    im = ax.imshow(
-        z, aspect="auto", extent=[xmin, xmax, ymin, ymax], origin="lower", zorder=zorder
-    )
+    im = ax.imshow(z, aspect="auto", extent=[xmin, xmax, ymin, ymax], origin="lower", zorder=zorder)
 
     xy = np.column_stack([x, y])
     xy = np.vstack([[xmin, ymin], xy, [xmax, ymin], [xmin, ymin]])
@@ -315,7 +335,7 @@ def find_nearest(array, value):
     array = np.asarray(array)
     idx = (np.abs(array - value)).argmin()
     return array[idx], idx
-    
+
 
 def apply_logscale(m, ticks, linthresh=1):
     """
@@ -333,6 +353,7 @@ def apply_logscale(m, ticks, linthresh=1):
     m = np.maximum(np.minimum(m, new_ticks[-1]), new_ticks[0])
     return m, new_ticks
 
+
 def standalone_colorbar(
     cmap,
     ticks,
@@ -345,19 +366,19 @@ def standalone_colorbar(
     width=2,
 ):
 
-    fig = plt.figure(figsize=(width, width/4))
+    fig = plt.figure(figsize=(width, width / 4))
     set_style(darkmode)
-    cmap=load_cmap(cmap)
-    img = plt.imshow(np.array([[0,1]]), cmap=cmap)
+    cmap = load_cmap(cmap)
+    img = plt.imshow(np.array([[0, 1]]), cmap=cmap)
     plt.gca().set_visible(False)
-    ax = plt.axes([0.1, 0.7, 0.8, 0.2]) #LBWH
+    ax = plt.axes([0.1, 0.7, 0.8, 0.2])  # LBWH
 
     if fontsize is None:
         fontsize = DEFAULT_FONTSIZES
 
     if ticklabels is None:
         ticklabels = format_list(ticks)
-    
+
     apply_colorbar(
         fig,
         ax,
@@ -369,9 +390,10 @@ def standalone_colorbar(
         norm=norm,
         cbar_shrink=shrink,
         cbar_pad=0.0,
-        cmap=cmap
+        cmap=cmap,
     )
 
+
 def apply_colorbar(
     fig,
     ax,
@@ -385,7 +407,7 @@ def apply_colorbar(
     cbar_pad=0.04,
     cbar_shrink=0.3,
     cmap=None,
-    orientation='horizontal',
+    orientation="horizontal",
 ):
     """
     This function applies a colorbar to the figure and formats the ticks.
@@ -393,14 +415,17 @@ def apply_colorbar(
 
     if image is None and cmap is not None:
         norm = mpl.colors.Normalize(vmin=ticks[0], vmax=ticks[-1])
-        cb = mpl.colorbar.ColorbarBase(ax, cmap=cmap,
-                                        norm=norm,
-                                        orientation=orientation,
-                                        ticks=ticks,)
+        cb = mpl.colorbar.ColorbarBase(
+            ax,
+            cmap=cmap,
+            norm=norm,
+            orientation=orientation,
+            ticks=ticks,
+        )
     else:
         cb = fig.colorbar(
             image,
-            #ax=ax,
+            # ax=ax,
             orientation=orientation,
             shrink=cbar_shrink,
             pad=cbar_pad,
@@ -409,23 +434,23 @@ def apply_colorbar(
         fontsize = DEFAULT_FONTSIZES
     if isinstance(unit, u.UnitBase):
         unit = unit.to_string("latex")
-    #if orientation == 'horizontal':
+    # if orientation == 'horizontal':
     #    cb.ax.set_xticklabels(ticklabels, size=fontsize["cbar_tick_label"])
     #    cb.ax.xaxis.set_label_text(unit, size=fontsize["cbar_label"])
-    #elif orientation == 'vertical':
+    # elif orientation == 'vertical':
     #    cb.ax.set_yticklabels(ticklabels, size=fontsize["cbar_tick_label"])
     #    cb.ax.yaxis.set_label_text(unit, size=fontsize["cbar_label"])
 
-    #cb = plt.gca().collections[-1].colorbar
-    #labels = cb.ax.xaxis.get_ticklabels()
+    # cb = plt.gca().collections[-1].colorbar
+    # labels = cb.ax.xaxis.get_ticklabels()
     ##ticks = cb.get_ticks()
-    #N = len(labels)
-    #for i, label in enumerate(labels):
+    # N = len(labels)
+    # for i, label in enumerate(labels):
     #    if i in [0, N//2, N-1]:
     #        continue
     #    label.set_visible(False)
-    
-    if  norm in ["linlog", "log"]:
+
+    if norm in ["linlog", "log"]:
         """
         Make logarithmic tick markers manually
         """
@@ -439,45 +464,43 @@ def apply_colorbar(
         # cb.set_ticks(np.concatenate((ticks,symlog(ticks_))), []) # Set major ticks
         logticks = symlog(ticks_, linthresh)
         logticks = [x for x in logticks if x not in ticks]
-        if orientation == 'horizontal':
-            cb.set_ticks(np.concatenate((ticks, logticks)))  # Set major ticks  
+        if orientation == "horizontal":
+            cb.set_ticks(np.concatenate((ticks, logticks)))  # Set major ticks
             cb.ax.set_xticklabels(ticklabels + [""] * len(logticks))
-        elif orientation == 'vertical':
-            #cb.ax.yaxis.set_ticks(np.concatenate((ticks, logticks)))  # Set major ticks  
-            #cb.ax.set_yticklabels(ticklabels + [""] * len(logticks))
+        elif orientation == "vertical":
+            # cb.ax.yaxis.set_ticks(np.concatenate((ticks, logticks)))  # Set major ticks
+            # cb.ax.set_yticklabels(ticklabels + [""] * len(logticks))
             pass
 
-
         # Minor tick log markers
-        
+
         # Linear range for linlog plotting
         minorticks = np.linspace(-linthresh, linthresh, 5) if linthresh > 0.0 else [0]
 
         # Make first range of logarithmic minor ticks
-        lt = 1 if norm=="log" else linthresh
+        lt = 1 if norm == "log" else linthresh
         minorticks2 = np.arange(2, 10) * lt
-        
 
         # Create range of minor ticks from min value to negative max
         for i in range(len(logticks_min)):
-            minorticks = np.concatenate((-(10 ** i) * minorticks2, minorticks))
+            minorticks = np.concatenate((-(10**i) * minorticks2, minorticks))
 
         # Create range of minor ticks from min value to positive max
         for i in range(len(logticks_max)):
-            minorticks = np.concatenate((minorticks, (10 ** i) * minorticks2))
+            minorticks = np.concatenate((minorticks, (10**i) * minorticks2))
 
         # Convert values to true logarithmic values
         minorticks = symlog(minorticks, linthresh)
 
         # Remove values outside of range
         minorticks = minorticks[(minorticks >= ticks[0]) & (minorticks <= ticks[-1])]
-        if orientation == 'horizontal':
+        if orientation == "horizontal":
             cb.ax.xaxis.set_ticks(minorticks, minor=True)
-        elif orientation == 'vertical':
+        elif orientation == "vertical":
             cb.ax.yaxis.set_ticks(minorticks, minor=True)
     # workaround for issue with viewers, see colorbar docstring
     cb.solids.set_edgecolor("face")
-    if orientation == 'horizontal':
+    if orientation == "horizontal":
         cb.ax.tick_params(
             which="both",
             axis="x",
@@ -485,7 +508,7 @@ def apply_colorbar(
             color="#3d3d3d",
         )
         cb.ax.xaxis.labelpad = 0
-    elif orientation == 'vertical':
+    elif orientation == "vertical":
         cb.ax.tick_params(
             which="both",
             axis="y",
@@ -495,10 +518,9 @@ def apply_colorbar(
         cb.ax.yaxis.labelpad = 0
 
         ylabels = cb.ax.get_yticklabels()
-        cb.ax.set_yticklabels(ylabels, Rotation= 90)
+        cb.ax.set_yticklabels(ylabels, Rotation=90)
 
-
-    return #cb
+    return  # cb
 
 
 def load_cmap(cmap):
@@ -508,48 +530,10 @@ def load_cmap(cmap):
 
     if cmap is None:
         cmap = "planck"
-    if "planck" in cmap:
-        if "planck_log" in cmap:  # logscale:
-            # setup nonlinear colormap
 
-            class GlogColormap(LinearSegmentedColormap):
-                name = cmap
-
-                def __init__(self, cmap, vmin=-1e3, vmax=1e7):
-                    self.cmap = cmap
-                    self.N = self.cmap.N
-                    self.vmin = vmin
-                    self.vmax = vmax
-
-                def is_gray(self):
-                    return False
-
-                def __call__(self, xi, alpha=1.0, **kw):
-                    x = xi * (self.vmax - self.vmin) + self.vmin
-                    yi = self.modsinh(x)
-                    # range 0-1
-                    yi = (yi + 3) / 10.0
-                    return self.cmap(yi, alpha)
-
-                def modsinh(self, x):
-                    return np.log10(0.5 * (x + np.sqrt(x ** 2 + 4)))
-
-            cmap_path = Path(data_dir.__path__[0]) / "planck_cmap_logscale.dat"
-            planck_cmap = np.loadtxt(cmap_path) / 255.0
-            cmap = ListedColormap(planck_cmap, "planck")
-            cmap = GlogColormap(cmap)
-        else:
-            cmap_path = Path(data_dir.__path__[0]) / "planck_cmap.dat"
-            planck_cmap = np.loadtxt(cmap_path) / 255.0
-            if cmap.endswith("_r"):
-                planck_cmap = planck_cmap[::-1]
-            cmap = ListedColormap(planck_cmap, "planck")
-    elif "wmap" in cmap:
-        cmap_path = Path(data_dir.__path__[0]) / "wmap_cmap.dat"
-        wmap_cmap = np.loadtxt(cmap_path) / 255.0
-        if cmap.endswith("_r"):
-            wmap_cmap = wmap_cmap[::-1]
-        cmap = ListedColormap(wmap_cmap, "wmap")
+    if cmap in ["planck", "planck_log", "wmap"]:
+        cmap_path =  cmap_path = Path(data_dir.__path__[0]) / f"{cmap}_cmap.dat"
+        cmap = ListedColormap(np.loadtxt(cmap_path) / 255.0, cmap)
     elif cmap.startswith("black2"):
         cmap = LinearSegmentedColormap.from_list(cmap, cmap.split("2"))
     else:
@@ -563,7 +547,6 @@ def load_cmap(cmap):
 
                 cmap = plt.get_cmap(cmap)
 
-    # print("Colormap:" + f" {cmap.name}")
     return cmap
 
 
@@ -582,18 +565,12 @@ def get_data(input, sig, comp, freq, fwhm, nside=None, sample=-1):
         if input.endswith(".h5"):
             if comp is None:
                 if freq is None:
-                    print(
-                        "[bold magenta]Warning! Neither frequency nor component selected. Plotting sky at 70GHz[/bold magenta]"
-                    )
-                data = SkyModel.from_chain(
-                    input, components=comp, nside=nside, samples=sample
-                )
+                    print("[bold magenta]Warning! Neither frequency nor component selected. Plotting sky at 70GHz[/bold magenta]")
+                data = SkyModel.from_chain(input, components=comp, nside=nside, samples=sample)
             else:
                 if freq is not None:
                     # If frequency is specified, simulate sky with model.
-                    data = SkyModel.from_chain(
-                        input, components=comp, nside=nside, samples=sample
-                    )
+                    data = SkyModel.from_chain(input, components=comp, nside=nside, samples=sample)
                 else:
                     chain = Chain(
                         input,
@@ -601,7 +578,8 @@ def get_data(input, sig, comp, freq, fwhm, nside=None, sample=-1):
                     lmax = chain.get(f"{comp}/{specparam}_lmax", samples=sample)
                     alms = chain.get(f"{comp}/{specparam}_alm", samples=sample)
                     fwhm_ = chain.parameters[comp]["fwhm"] * u.arcmin
-                    if nside is None: nside = chain.parameters[comp]["nside"]
+                    if nside is None:
+                        nside = chain.parameters[comp]["nside"]
                     pol = True if specparam == "amp" and alms.shape[0] == 3 else False
                     # PROBLEM! Get issue with nside when udgrading directly to low nside
                     data = hp.alm2map(
@@ -626,9 +604,7 @@ def get_data(input, sig, comp, freq, fwhm, nside=None, sample=-1):
         """
         if comp is None:
             if freq is None:
-                print(
-                    "[bold magenta]Warning! Neither frequency nor component selected. Plotting sky at 70GHz[/bold magenta]"
-                )
+                print("[bold magenta]Warning! Neither frequency nor component selected. Plotting sky at 70GHz[/bold magenta]")
                 freq = 70 * u.GHz
             comp = "freqmap"
             m = data(freq, fwhm=fwhm)
@@ -637,14 +613,15 @@ def get_data(input, sig, comp, freq, fwhm, nside=None, sample=-1):
                 if freq is None:
                     # Get map at reference frequency if freq not specified
                     freq_ref = data[comp].freq_ref
-                    freq = freq_ref.value
+                    freq = (freq_ref.value).squeeze()
                     m = data[comp].amp
                     if comp == "radio":
                         m = data(freq_ref, fwhm=fwhm, components=[comp])
+                    
                     try:
-                        freq = round(freq.squeeze()[sig], 5) * freq_ref.unit
+                        freq = np.round(freq[sig], 5) * freq_ref.unit
                     except IndexError:
-                        freq = round(freq, 5) * freq_ref.unit
+                        freq = np.round(freq, 5) * freq_ref.unit
                 else:
                     # If freq is specified, scale with sky model
                     m = data(freq, fwhm=fwhm, components=[comp])
@@ -652,26 +629,24 @@ def get_data(input, sig, comp, freq, fwhm, nside=None, sample=-1):
                 m = data[comp].spectral_parameters[specparam]
 
                 if len(m[sig]) == 1:
-                    warnings.warn(
-                        "Same value across the whole sky, mapping to array of length Npix"
-                    )
+                    warnings.warn("Same value across the whole sky, mapping to array of length Npix")
                     m = np.full(hp.nside2npix(data.nside), m[sig])
 
     elif isinstance(data, np.ndarray):
         m = data
         if m.ndim == 1 and sig > 0 and not isinstance(input, str):
-            print(
-                f"[magenta]Input array is 1d, specified signal will only be used for labeling, make sure this is correct.[/magenta]"
-            )
+            print(f"[magenta]Input array is 1d, specified signal will only be used for labeling, make sure this is correct.[/magenta]")
     else:
-        raise TypeError(
-            f"Type {type(data)} of data not supported"
-            f"Supports numpy array, cosmoglobe model object or fits file string"
-        )
+        raise TypeError(f"Type {type(data)} of data not supported" f"Supports numpy array, cosmoglobe model object or fits file string")
 
     # Make sure it is a 1d array
     if m.ndim > 1:
-        m = m[sig]
+        if sig>np.shape(m)[0]-1:
+            warnings.warn(f"Index {sig} out of data range {np.shape(m)}, returning empty map")
+            m = np.zeros(np.shape(m[-1]))+hp.UNSEEN
+        else:
+            m = m[sig]
+
 
     # Convert astropy map to numpy array
     if isinstance(m, u.Quantity):
@@ -679,7 +654,7 @@ def get_data(input, sig, comp, freq, fwhm, nside=None, sample=-1):
 
     # ud_grade map
     if nside is not None and nside != hp.get_nside(m):
-        print("Ud_grading map")
+        print("ud_grading map")
         m = hp.ud_grade(m, nside)
 
     # Smooth map
@@ -706,17 +681,12 @@ def get_params(**params):
         try:
             autoparams = autoparams[params["comp"]]
         except KeyError:
-            print(
-                f"[magenta]Component label {params['comp']} not found. Using unidentified profile.[/magenta]"
-            )
+            print(f"[magenta]Component label {params['comp']} not found. Using unidentified profile.[/magenta]")
             print(f"available keys are: {autoparams.keys()}")
             autoparams = autoparams["unidentified"]
 
         # Replace default values if None
-        params = {
-            key: (autoparams[key] if key in autoparams and value is None else value)
-            for key, value in params.items()
-        }
+        params = {key: (autoparams[key] if key in autoparams and value is None else value) for key, value in params.items()}
 
         # NOTE: This is really ugly code for selecting pol parameters
         # Pick polarization or temperature
@@ -737,17 +707,10 @@ def get_params(**params):
         specials = ["residual", "freqmap", "bpcorr", "smap"]
         if any(j in params["comp"] for j in specials):
             if freq is not None:
-                params["rlabel"] = (
-                    params["rlabel"]
-                    + "{"
-                    + f'{("%.5f" % freq.value).rstrip("0").rstrip(".")}'
-                    + "}"
-                )
+                params["rlabel"] = params["rlabel"] + "{" + f'{("%.5f" % freq.value).rstrip("0").rstrip(".")}' + "}"
             else:
                 params["rlabel"] = None
-                warnings.warn(
-                    f'Specify frequency with -freq for automatic frequency labeling with the "freqmap" profile'
-                )
+                warnings.warn(f'Specify frequency with -freq for automatic frequency labeling with the "freqmap" profile')
 
         """
         # NOTE: This probably doesnt work with the current state of the comp
@@ -766,22 +729,13 @@ def get_params(**params):
 
         # Specify at which frequency we are observing in unit lable
         if freq is not None and params["unit"] is not None:
-            params["unit"] = (
-                f'{params["unit"]}\,@\,{("%.5f" % freq.value).rstrip("0").rstrip(".")}'
-                + "\,\mathrm{GHz}"
-            )
+            params["unit"] = f'{params["unit"]}\,@\,{("%.5f" % freq.value).rstrip("0").rstrip(".")}' + "\,\mathrm{GHz}"
 
         # In the case that a difference frequency than the reference
         # is requested for a component map.
         if params["ticks"] == None:
-            if (
-                freq is not None
-                and params["freq_ref"] != freq.value
-                and params["comp"] not in specials
-            ):
-                warnings.warn(
-                    f"Input frequency is different from reference, autosetting ticks"
-                )
+            if freq is not None and params["freq_ref"] != freq.value and params["comp"] not in specials:
+                warnings.warn(f"Input frequency is different from reference, autosetting ticks")
                 print(f'input: {freq}, reference: {params["freq_ref"]}')
                 params["ticks"] = "auto"
 
@@ -809,10 +763,10 @@ def get_params(**params):
                 params["ticks"][-1] = params["max"]
 
     # Ticks and ticklabels
-    if params["ticks"] == "auto" or params["norm"] == "hist":
-        params["ticks"] = get_percentile(params["data"], 97.5)
+    if params["ticks"] == "auto" or "auto" in params["ticks"]:
+        params["ticks"] = get_percentile(params["data"], 99)
     elif None in params["ticks"]:
-        pmin, pmax = get_percentile(params["data"], 97.5)
+        pmin, pmax = get_percentile(params["data"], 99)
         if params["ticks"][0] is None:
             params["ticks"][0] = pmin
         if params["ticks"][-1] is None:
@@ -825,42 +779,39 @@ def get_params(**params):
                 params[key] = r"$" + params[key] + "$"
 
     # Special case if dipole is detected in freqmap
-    if (
-        params["comp"] == "freqmap"
-        and params["min"] is None
-        and params["max"] is None
-        and params["rng"] is None
-    ):
+    if params["comp"] == "freqmap" and params["min"] is None and params["max"] is None and params["rng"] is None:
         # if colorbar is super-saturated
-        while (
-            len(params["data"][abs(params["data"]) > params["ticks"][-1]])
-            / len(params["data"].ravel())
-            > 0.7
-        ):
+        while len(params["data"][abs(params["data"]) > params["ticks"][-1]]) / len(params["data"].ravel()) > 0.7:
             params["ticks"] = [tick * 10 for tick in params["ticks"]]
             print("[magenta]Colormap saturated. Expanding color-range.[/magenta]")
 
     # Create ticklabels from final ticks
     params["ticklabels"] = format_list(params["ticks"])
 
+    # Set planck as default cmap
+    if params["cmap"] is None:
+        params["cmap"] = "planck"
+    
     return params
 
+
 def mask_map(m, mask):
     """
     Apply a mask to a map
     """
-    
+
     m = hp.ma(m)
     m.mask = mask
-    #Alternative
-        
-    #mask = mask*np.NaN
-    #m *= mask
+    # Alternative
+
+    # mask = mask*np.NaN
+    # m *= mask
     return m
 
+
 def create_70GHz_mask(sky_frac, nside=256, pol=False):
     """
-    Creates a mask from a 70GHz frequency map at nside=256 for a 
+    Creates a mask from a 70GHz frequency map at nside=256 for a
     threshold corresponding to a given sky fraction (in %). The 70GGz
     map is chosen due to it containing a large portion of all low-frequency
     sky components.
@@ -874,54 +825,54 @@ def create_70GHz_mask(sky_frac, nside=256, pol=False):
         Mask covering the sky for a given sky fraction.
     """
     # Read amplitude map to use for thresholding
-    field=(1,2) if pol else 0    
-    template = hp.read_map(Path(data_dir.__path__[0]) / 'mask_template_n256.fits', dtype=np.float64, field=field)
-    if pol: 
-        template = np.sqrt(template[0]**2+template[1]**2)
+    field = (1, 2) if pol else 0
+    template = hp.read_map(
+        Path(data_dir.__path__[0]) / "mask_template_n256.fits",
+        dtype=np.float64,
+        field=field,
+    )
+    if pol:
+        template = np.sqrt(template[0] ** 2 + template[1] ** 2)
     template = hp.ma(template)
 
-    if nside!=256:
+    if nside != 256:
         template = hp.ud_grade(template, nside)
 
-
     # Masking based on sky fraction is not trivial. Here we manually compute
-    # the sky fraction by masking all pixels with amplitudes larger than a 
-    # given percentage of the maximum map amplitude. The pixels masks then 
+    # the sky fraction by masking all pixels with amplitudes larger than a
+    # given percentage of the maximum map amplitude. The pixels masks then
     # correspond to a sky fraction. We tabulate the amplitude percentage and
     # sky fraction for a range, and interpolate from this table.
-    amp_percentages = np.flip(np.arange(1,101))
+    amp_percentages = np.flip(np.arange(1, 101))
     fracs = []
     mask = np.zeros(len(template), dtype=np.bool)
 
     for i in range(len(amp_percentages)):
         mask = np.zeros(len(template), dtype=np.bool)
         masked_template = np.abs(hp.ma(template))
-        mask[np.where(np.log(masked_template) > 
-            (amp_percentages[i]/100)*np.nanmax(np.log(masked_template)))] = 1
+        mask[np.where(np.log(masked_template) > (amp_percentages[i] / 100) * np.nanmax(np.log(masked_template)))] = 1
         masked_template.mask = mask
 
-        frac = ((len(masked_template)-masked_template.count())
-                /len(masked_template))*100
+        frac = ((len(masked_template) - masked_template.count()) / len(masked_template)) * 100
         fracs.append(frac)
 
-    amp_percentage = np.interp(100-sky_frac, fracs, amp_percentages)
+    amp_percentage = np.interp(100 - sky_frac, fracs, amp_percentages)
 
     mask = np.zeros(len(template), dtype=np.bool)
     masked_template = np.abs(hp.ma(template))
-    mask[np.where(np.log(masked_template) > 
-        (amp_percentage/100)*np.nanmax(np.log(masked_template)))] = 1
+    mask[np.where(np.log(masked_template) > (amp_percentage / 100) * np.nanmax(np.log(masked_template)))] = 1
 
     return mask
 
 
-def seds_from_model(nu, model, nside=None, pol=False, sky_fractions=(25,85)):
-    ignore_comps=["radio"]
+def seds_from_model(nu, model, nside=None, pol=False, sky_fractions=(25, 85)):
+    ignore_comps = ["radio"]
     comps = model.components
-    if nside is None or nside==model.nside:
+    if nside is None or nside == model.nside:
         nside = model.nside
-        udgrade=False
+        udgrade = False
     else:
-        udgrade=True
+        udgrade = True
 
     masks = np.zeros((len(sky_fractions), hp.nside2npix(nside)))
 
@@ -931,39 +882,40 @@ def seds_from_model(nu, model, nside=None, pol=False, sky_fractions=(25,85)):
     # SED dictionary with T and P, skyfractions and the value per nu
     seds = {comp: np.zeros((2, len(sky_fractions), len(nu))) for comp in model.components}
     for key, value in comps.items():
-        if key in ignore_comps: continue
+        if key in ignore_comps:
+            continue
 
         for i, mask in enumerate(masks):
             specinds = {}
             for specind, m in value.spectral_parameters.items():
-                if m.shape[-1]!=1: 
-                    m = np.mean(mask_map(m,mask), axis=1).reshape(-1,1)*value.spectral_parameters[specind].unit
+                if m.shape[-1] != 1:
+                    m = np.mean(mask_map(m, mask), axis=1).reshape(-1, 1) * value.spectral_parameters[specind].unit
                 specinds[specind] = m
 
             amp = hp.ud_grade(value.amp, nside) if udgrade else value.amp
-            amp[0,amp[0]<0.0]=0.0 #abs(amp)
+            amp[0, amp[0] < 0.0] = 0.0  # abs(amp)
             amp = mask_map(amp, mask)
 
-            amp_pol=0
+            amp_pol = 0
             if pol:
-                if amp.shape[0]>1:
-                    amp_pol = rms_amp(np.sqrt(amp[1]**2+amp[2]**2))
+                if amp.shape[0] > 1:
+                    amp_pol = rms_amp(np.sqrt(amp[1] ** 2 + amp[2] ** 2))
             amp = rms_amp(amp[0])
 
-            
             if key == "cmb":
-                freq_scaling=(np.ones(len(nu)) * Unit("uK_CMB")).to("uK_RJ", equivalencies=cmb_equivalencies(nu*u.GHz))
-                seds[key][0,i,:] = 45*freq_scaling   # TEMP
-                seds[key][1,i,:] = 0.67*freq_scaling # POL
+                freq_scaling = (np.ones(len(nu)) * Unit("uK_CMB")).to("uK_RJ", equivalencies=cmb_equivalencies(nu * u.GHz))
+                seds[key][0, i, :] = 45 * freq_scaling  # TEMP
+                seds[key][1, i, :] = 0.67 * freq_scaling  # POL
             else:
-                freq_scaling=value.get_freq_scaling(nu*u.GHz,**specinds)
-                k = 1 if freq_scaling.shape[0]>1 else 0
-                seds[key][0,i,:] = amp*freq_scaling[0]
-                seds[key][1,i,:] = amp_pol*freq_scaling[k]
+                freq_scaling = value.get_freq_scaling(nu * u.GHz, **specinds)
+                k = 1 if freq_scaling.shape[0] > 1 else 0
+                seds[key][0, i, :] = amp * freq_scaling[0]
+                seds[key][1, i, :] = amp_pol * freq_scaling[k]
 
     return seds
 
+
 def rms_amp(m):
-    n = len(m)-np.sum(m.mask)
+    n = len(m) - np.sum(m.mask)
     m -= np.mean(m)
-    return np.sqrt(np.sum(m**2)/n)
+    return np.sqrt(np.sum(m**2) / n)
