@@ -1,6 +1,7 @@
 from typing import Tuple
 import astropy.constants as const
-from astropy.units import Unit, Quantity
+from astropy.units import Quantity
+from cosmoglobe.sky._units import Unit
 
 DEFAULT_BEAM_FWHM: Quantity = 0.0 * Unit("arcmin")
 DEFAULT_OUTPUT_UNIT: Unit = Unit("uK_RJ")
